--[[----------------------------------------------------------------------------
	Copyright 2007,2008 João Liborio Cardoso
	All rights reserved
	
	Mail Notifier is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License version 3 as published by the Free Software Foundation.
	Mail Notifier is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License (<http://www.gnu.org/licenses/>) for more details.
---------------------------------------------------------------------------]]--

MailNotifier = CreateFrame("Frame")
local WrongEvent, NumbMails, L, sets, Indicator, Shine = 0


--[[ Startup ]]--

function MailNotifier:Load()
	Indicator = MiniMapMailFrame:CreateFontString("MailNotifierIndicator", "OVERLAY")
	Indicator:SetFontObject("NumberFontNormal")
	Indicator:SetPoint("Center", MiniMapMailFrame, "Center", -1, 1)
	Indicator:SetJustifyH("CENTER")

	Shine = MiniMapMailFrame:CreateTexture("MailNotifierShine", "OVERLAY")
	Shine:SetPoint("CENTER", MiniMapMailFrame, "CENTER", 3, 3)
	Shine:SetTexture("Interface\\ComboFrame\\ComboPoint")
	Shine:SetHeight(32) Shine:SetWidth(32)
	Shine:SetTexCoord(0.5625, 1, 0, 1)
	Shine:SetBlendMode("ADD")
	Shine:Hide()
	
	self:RegisterEvent("PLAYER_ENTERING_WORLD")
	self:RegisterEvent("UPDATE_PENDING_MAIL")
	self:RegisterEvent("MAIL_INBOX_UPDATE")
	self:RegisterEvent("VARIABLES_LOADED")
	self:RegisterEvent("CHAT_MSG_SYSTEM")
	self:RegisterEvent("MAIL_SHOW")
	
	self:SetScript("OnEvent", function() self[event](self) end)
	hooksecurefunc("MinimapMailFrameUpdate", function() self:UpdateTooltip() end)
end

function MailNotifier:VARIABLES_LOADED()
	MailNotifier_SV = MailNotifier_SV or {unread = 0}
	L, sets = MailNotifier.Locals, MailNotifier_SV
	self:UpdateIndicator()
end


--[[ API ]]--

function MailNotifier:AddNewMail()
	sets.unread = sets.unread + 1
	UIFrameFlash(MailNotifierShine, 0.7, 0.7, 10.4, nil, 0.6)
	PlaySoundFile("Interface\\AddOns\\MailNotifier\\NewMail.wav")
	self:UpdateIndicator()
end

function MailNotifier:UpdateIndicator()
	if(sets.unread > 1) then
		Indicator:SetText(sets.unread)
		Indicator:Show()
	else
		Indicator:Hide()
	end
end

function MailNotifier:UpdateTooltip()
	if ( sets.unread > 0 ) then
		if ( sender1 or sender2 or sender3 ) then
			toolText = gsub(toolText, L.Garbage, "")
		else
			toolText = ""
		end
		if ( sets.unread > 1 ) then
			GameTooltip:SetText(format(L.HaveMails, sets.unread, toolText))
		else
			GameTooltip:SetText(format(L.HaveMail, sets.unread, toolText))
		end
	end
end

function MailNotifier:MatchSystemMessage(arg1, arg2)
	arg2 = strsplit("%%s", arg2)
	return strfind(arg1, arg2)
end


--[[ Events ]]--

function MailNotifier:PLAYER_ENTERING_WORLD()
	if HasNewMail() then
		WrongEvent = true
	end
end

function MailNotifier:UPDATE_PENDING_MAIL()
	if WrongEvent then
		WrongEvent = nil
	else
		if HasNewMail() then
			self:AddNewMail()
		end
	end
end

function MailNotifier:CHAT_MSG_SYSTEM()
	if self:MatchSystemMessage(arg1, ERR_AUCTION_OUTBID_S) then
		self:AddNewMail()
		MiniMapMailFrame:GetScript('OnEvent')()
	elseif arg1 == ERR_AUCTION_REMOVED or self:MatchSystemMessage(arg1, ERR_AUCTION_WON_S) then
		WrongEvent = true
	end
end

function MailNotifier:MAIL_SHOW()
	NumMails = GetInboxNumItems()
end


function MailNotifier:MAIL_INBOX_UPDATE()
	local InboxNumItems = GetInboxNumItems()
	sets.unread = 0
	
	for i = 1, InboxNumItems do
		if not select(9, GetInboxHeaderInfo(i)) then
			sets.unread = sets.unread + 1
		end
	end
	if InboxNumItems ~= NumMails then
		WrongEvent = true
	end
	
	self:UpdateIndicator()
end


--[[ Call Addon ]]--

MailNotifier:Load()